Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bitmap_font_simpletest.py
    :caption: examples/bitmap_font_simpletest.py
    :linenos:

Label simple test
-----------------

This example uses ``adafruit_display_text.label`` to display text using a custom font
loaded by ``adafruit_bitmap_font``

.. literalinclude:: ../examples/bitmap_font_label_simpletest.py
    :caption: examples/bitmap_font_label_simpletest.py
    :linenos:

Displayio simple test
---------------------

This example uses ``adafruit_bitmap_font`` to load a font and fill a bitmap with
pixels matching glyphs from a given String

.. literalinclude:: ../examples/bitmap_font_displayio_simpletest.py
    :caption: examples/bitmap_font_displayio_simpletest.py
    :linenos:

Label MagTag
------------

This example uses ``adafruit_display_text.label`` to display text using a custom font
loaded by ``adafruit_bitmap_font``.

.. literalinclude:: ../examples/bitmap_font_label_magtag.py
    :caption: examples/bitmap_font_label_magtag.py
    :linenos:

Fork Awesome icons
------------------

This example uses ``adafruit_display_text.label`` to display fork awesome
icons.

.. literalinclude:: ../examples/bitmap_font_label_forkawesome.py
    :caption: examples/bitmap_font_label_forkawesome.py
    :linenos:
